@@ -284,21 +284,20 @@ impl Visit for SpanVisualizer<'_> {
     mtd!(AtTextValue, visit_at_text_value);
     mtd!(AttrSelector, visit_attr_selector);
     mtd!(BinValue, visit_bin_value);
-    mtd!(BraceValue, visit_brace_value);
     mtd!(ClassSelector, visit_class_selector);
     mtd!(SpaceValues, visit_space_values);
     mtd!(ComplexSelector, visit_complex_selector);
     mtd!(Combinator, visit_combinator);
     mtd!(CompoundSelector, visit_compound_selector);
     mtd!(Block, visit_block);
-    mtd!(RoundBracketBlock, visit_round_bracket_block);
-    mtd!(SquareBracketBlock, visit_square_bracket_block);
+    mtd!(SimpleBlock, visit_simple_block);
     mtd!(Function, visit_function);
     mtd!(HashValue, visit_hash_value);
     mtd!(NestingSelector, visit_nesting_selector);
     mtd!(IdSelector, visit_id_selector);
     mtd!(TypeSelector, visit_type_selector);
-    mtd!(Num, visit_num);
+    mtd!(Number, visit_number);
+    mtd!(Ratio, visit_ratio);
     mtd!(PercentValue, visit_percent_value);
     mtd!(Declaration, visit_declaration);
     mtd!(Nth, visit_nth);
